@@ -686,12 +686,11 @@ book_view_thread (gpointer data)
 	GList *contacts = NULL, *temp_list = NULL;
 	//Number of multiple restriction to apply
 	unsigned int res_count = 6;
-	GPtrArray *contacts_array = g_ptr_array_new();
 	
 	if (enable_debug)
 		printf("mapi: book view\n");
 	
-	bonobo_object_ref (book_view);
+	g_object_ref (book_view);
 	e_flag_set (closure->running);
 						
 	e_data_book_view_notify_status_message (book_view, "Searching...");
@@ -699,12 +698,11 @@ book_view_thread (gpointer data)
 						
 	switch (priv->mode) {
 		case GNOME_Evolution_Addressbook_MODE_REMOTE:
-			exchange_mapi_util_get_gal (contacts_array);
 			if (!exchange_mapi_connection_exists ()) {
 				e_book_backend_notify_auth_required (E_BOOK_BACKEND (backend));
 				e_data_book_view_notify_complete (book_view,
 							GNOME_Evolution_Addressbook_AuthenticationRequired);
-				bonobo_object_unref (book_view);
+				g_object_unref (book_view);
 				return;
 			}
 		
@@ -719,7 +717,7 @@ book_view_thread (gpointer data)
 						get_contacts_from_cache (backend, query, ids, book_view, closure);
 						g_ptr_array_free (ids, TRUE);
 					}
-					bonobo_object_unref (book_view);
+					g_object_unref (book_view);
 					return;
 				}
 			
@@ -744,7 +742,7 @@ book_view_thread (gpointer data)
 									  GNOME_Evolution_Addressbook_Success);
 				if (temp_list)
 					 g_list_free (temp_list);
-				bonobo_object_unref (book_view);
+				g_object_unref (book_view);
 				return;
 			}
 		
@@ -760,7 +758,7 @@ book_view_thread (gpointer data)
 			if (e_flag_is_set (closure->running))
 				e_data_book_view_notify_complete (book_view,
 								  GNOME_Evolution_Addressbook_Success);
-			bonobo_object_unref (book_view);
+			g_object_unref (book_view);
 			break;
 		}
 	}
@@ -829,6 +827,12 @@ e_book_backend_mapi_gal_stop_book_view (EBookBackend  *backend,
 	/* FIXME : provide implmentation */
 }
 
+static void
+e_book_backend_mapi_gal_remove (EBookBackend *backend, EDataBook *book, guint32 opid)
+{
+	e_data_book_respond_remove (book, opid, GNOME_Evolution_Addressbook_PermissionDenied);
+}
+
 static void e_book_backend_mapi_gal_class_init (EBookBackendMAPIGALClass *klass)
 {
 	GObjectClass  *object_class = G_OBJECT_CLASS (klass);
@@ -853,6 +857,7 @@ static void e_book_backend_mapi_gal_class_init (EBookBackendMAPIGALClass *klass)
 	parent_class->get_supported_fields	 = e_book_backend_mapi_gal_get_supported_fields;
 	parent_class->get_required_fields	 = e_book_backend_mapi_gal_get_required_fields;
 	parent_class->set_mode                   = e_book_backend_mapi_gal_set_mode;
+	parent_class->remove			 = e_book_backend_mapi_gal_remove;
 	object_class->dispose                    = e_book_backend_mapi_gal_dispose;
 
 
