@@ -359,6 +359,7 @@ e_cal_backend_mapi_remove (ECalBackendSync *backend, EDataCal *cal)
 	return GNOME_Evolution_Calendar_Success;
 }
 
+#if 0
 static const char *
 get_element_type (icalcomponent_kind kind)
 {
@@ -375,6 +376,7 @@ get_element_type (icalcomponent_kind kind)
 	return type;
 
 }
+#endif
 
 static void 
 notify_progress (ECalBackendMAPI *cbmapi, guint64 index, guint64 total)
@@ -575,8 +577,8 @@ get_deltas (gpointer handle)
 						NULL, 0, NULL, NULL, 
 						mapi_cal_get_changes_cb, cbmapi, 
 						MAPI_OPTIONS_FETCH_ALL)) {
-			/* FIXME: better string please... */
-			e_cal_backend_notify_error (E_CAL_BACKEND (cbmapi), _("Error fetching changes from the server. Removing the cache might help."));
+			/* FIXME: String : We need to restart evolution-data-server */
+			e_cal_backend_notify_error (E_CAL_BACKEND (cbmapi), _("Error fetching changes from the server."));
 //			e_file_cache_thaw_changes (E_FILE_CACHE (priv->cache));
 			g_static_mutex_unlock (&updating);
 			return FALSE;
@@ -586,8 +588,8 @@ get_deltas (gpointer handle)
 						exchange_mapi_cal_util_build_name_id, GINT_TO_POINTER(kind), 
 						mapi_cal_get_changes_cb, cbmapi, 
 						MAPI_OPTIONS_FETCH_ALL)) {
-		/* FIXME: better string please... */
-		e_cal_backend_notify_error (E_CAL_BACKEND (cbmapi), _("Error fetching changes from the server. Removing the cache might help."));
+		/* FIXME: String : We need to restart evolution-data-server */
+		e_cal_backend_notify_error (E_CAL_BACKEND (cbmapi), _("Error fetching changes from the server."));
 //		e_file_cache_thaw_changes (E_FILE_CACHE (priv->cache));
 		g_static_mutex_unlock (&updating);
 		return FALSE;
@@ -612,8 +614,8 @@ get_deltas (gpointer handle)
 						NULL, NULL, 
 						handle_deleted_items_cb, cbmapi, 
 						0)) {
-		/* FIXME: better string please... */
-		e_cal_backend_notify_error (E_CAL_BACKEND (cbmapi), _("Error fetching changes from the server. Removing the cache might help."));
+		/* FIXME: String : We need to restart evolution-data-server */
+		e_cal_backend_notify_error (E_CAL_BACKEND (cbmapi), _("Error fetching changes from the server."));
 		priv->cache_keys = NULL;
 		g_static_mutex_unlock (&updating);
 		return FALSE;
@@ -1302,6 +1304,7 @@ e_cal_backend_mapi_create_object (ECalBackendSync *backend, EDataCal *cal, char
 	GSList *streams = NULL;
 	struct cbdata cbdata;
 	struct Binary_r globalid;
+	struct icaltimetype current;
 
 	cbmapi = E_CAL_BACKEND_MAPI (backend);
 	priv = cbmapi->priv;
@@ -1326,6 +1329,10 @@ e_cal_backend_mapi_create_object (ECalBackendSync *backend, EDataCal *cal, char
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomp);
 
+	current = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
+ 	e_cal_component_set_created (comp, &current);
+ 	e_cal_component_set_last_modified (comp, &current);
+
 	/* FIXME: [WIP] Add support for recurrences */
 	if (e_cal_component_has_recurrences (comp)) {
 		GByteArray *ba = exchange_mapi_cal_util_rrule_to_bin (comp, NULL); 
@@ -1391,7 +1398,10 @@ e_cal_backend_mapi_create_object (ECalBackendSync *backend, EDataCal *cal, char
 
 			tmp = exchange_mapi_util_mapi_id_to_string (mid);
 			e_cal_component_set_uid (comp, tmp);
-			g_free (tmp);
+			if (uid)
+				*uid = tmp;
+			else
+				g_free (tmp);
 
 			e_cal_component_commit_sequence (comp);
 			e_cal_backend_cache_put_component (priv->cache, comp);
@@ -1488,7 +1498,8 @@ e_cal_backend_mapi_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 	GSList *attachments = NULL;
 	struct cbdata cbdata;
 	gboolean no_increment = FALSE;
-	icalproperty *prop; 
+	icalproperty *prop;
+	struct icaltimetype current;
 
 	*old_object = *new_object = NULL;
 	cbmapi = E_CAL_BACKEND_MAPI (backend);
@@ -1524,6 +1535,9 @@ e_cal_backend_mapi_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomp);
 
+	current = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
+ 	e_cal_component_set_last_modified (comp, &current);
+
 	/* FIXME: [WIP] Add support for recurrences */
 	if (e_cal_component_has_recurrences (comp)) {
 		GByteArray *ba = exchange_mapi_cal_util_rrule_to_bin (comp, NULL); 
@@ -2234,6 +2248,7 @@ e_cal_backend_mapi_set_mode (ECalBackend *backend, CalMode mode)
 {
 	ECalBackendMAPI *cbmapi;
 	ECalBackendMAPIPrivate *priv;
+	gboolean re_open = FALSE;
 
 	cbmapi = E_CAL_BACKEND_MAPI (backend);
 	priv = cbmapi->priv;
@@ -2246,6 +2261,8 @@ e_cal_backend_mapi_set_mode (ECalBackend *backend, CalMode mode)
 
 	g_mutex_lock (priv->mutex);
 
+	re_open = priv->mode == CAL_MODE_LOCAL && mode == CAL_MODE_REMOTE;
+
 	priv->mode_changed = TRUE;
 	switch (mode) {
 		case CAL_MODE_REMOTE:
@@ -2253,8 +2270,7 @@ e_cal_backend_mapi_set_mode (ECalBackend *backend, CalMode mode)
 			priv->read_only = FALSE;
 			e_cal_backend_notify_mode (backend, GNOME_Evolution_Calendar_CalListener_MODE_SET,
 					GNOME_Evolution_Calendar_MODE_REMOTE);
-			e_cal_backend_notify_readonly (backend, priv->read_only);
-			if (e_cal_backend_mapi_is_loaded (backend))
+			if (e_cal_backend_mapi_is_loaded (backend) && re_open)
 		              e_cal_backend_notify_auth_required(backend);
 			break;
 		case CAL_MODE_LOCAL:
@@ -2263,7 +2279,6 @@ e_cal_backend_mapi_set_mode (ECalBackend *backend, CalMode mode)
 			/* do we have to close the connection here ? */
 			e_cal_backend_notify_mode (backend, GNOME_Evolution_Calendar_CalListener_MODE_SET,
 					GNOME_Evolution_Calendar_MODE_REMOTE);
-			e_cal_backend_notify_readonly (backend, priv->read_only);
 			break;
 		default:
 			e_cal_backend_notify_mode (backend, GNOME_Evolution_Calendar_CalListener_MODE_NOT_SUPPORTED,
