@@ -214,28 +214,22 @@ exchange_mapi_cal_util_fetch_attachments (ECalComponent *comp, GSList **attach_l
 
 		sfname = g_filename_from_uri (sfname_uri, NULL, NULL);
 		mapped_file = g_mapped_file_new (sfname, FALSE, &error);
-		filename = g_path_get_basename (sfname);
+		filename = g_strdup (g_strrstr (sfname, uid));
 
-		if (mapped_file) {
+		if (mapped_file && g_str_has_prefix (filename, uid)) {
 			ExchangeMAPIAttachment *attach_item;
 			ExchangeMAPIStream *stream; 
 			guint8 *attach = (guint8 *) g_mapped_file_get_contents (mapped_file);
 			guint filelength = g_mapped_file_get_length (mapped_file);
-			const gchar *split_name;
+			const gchar *split_name = (filename + strlen (uid) + strlen ("-"));
 			uint32_t flag; 
 
-			if (g_str_has_prefix (filename, uid)) {
-				split_name = (filename + strlen (uid) + strlen ("-"));
-			} else {
-				split_name = filename;
-			}
-
 			new_attach_list = g_slist_append (new_attach_list, g_strdup (sfname_uri));
 
 			attach_item = g_new0 (ExchangeMAPIAttachment, 1);
 
 			attach_item->cValues = 4; 
-			attach_item->lpProps = g_new0 (struct SPropValue, attach_item->cValues + 1);
+			attach_item->lpProps = g_new0 (struct SPropValue, 4); 
 
 			flag = ATTACH_BY_VALUE; 
 			set_SPropValue_proptag(&(attach_item->lpProps[0]), PR_ATTACH_METHOD, (const void *) (&flag));
@@ -264,7 +258,7 @@ exchange_mapi_cal_util_fetch_attachments (ECalComponent *comp, GSList **attach_l
 #else
 			g_mapped_file_free (mapped_file);
 #endif
-		} else if (error) {
+		} else {
 			g_debug ("Could not map %s: %s \n", sfname_uri, error->message);
 			g_error_free (error);
 		}
@@ -305,8 +299,8 @@ exchange_mapi_cal_util_fetch_organizer (ECalComponent *comp, GSList **recip_list
 			recipient->email_id = (org);
 
 		/* Required properties - set them always */
+		recipient->in.req_lpProps = g_new0 (struct SPropValue, 5);
 		recipient->in.req_cValues = 5;
-		recipient->in.req_lpProps = g_new0 (struct SPropValue, recipient->in.req_cValues + 1);
 
 		val = 0;
 		set_SPropValue_proptag (&(recipient->in.req_lpProps[0]), PR_SEND_INTERNET_ENCODING, (const void *)&val);
@@ -327,8 +321,8 @@ exchange_mapi_cal_util_fetch_organizer (ECalComponent *comp, GSList **recip_list
 		set_SPropValue_proptag (&(recipient->in.req_lpProps[4]), PR_RECIPIENT_DISPLAY_NAME, (const void *)(str));
 
 		/* External recipient properties - set them only when the recipient is unresolved */
+		recipient->in.ext_lpProps = g_new0 (struct SPropValue, 5);
 		recipient->in.ext_cValues = 5;
-		recipient->in.ext_lpProps = g_new0 (struct SPropValue, recipient->in.ext_cValues + 1);
 
 		val = DT_MAILUSER;
 		set_SPropValue_proptag (&(recipient->in.ext_lpProps[0]), PR_DISPLAY_TYPE, (const void *)&val);
@@ -377,8 +371,8 @@ exchange_mapi_cal_util_fetch_recipients (ECalComponent *comp, GSList **recip_lis
 			recipient->email_id = (str);
 
 		/* Required properties - set them always */
+		recipient->in.req_lpProps = g_new0 (struct SPropValue, 5);
 		recipient->in.req_cValues = 5;
-		recipient->in.req_lpProps = g_new0 (struct SPropValue, recipient->in.req_cValues + 1);
 
 		val = 0;
 		set_SPropValue_proptag (&(recipient->in.req_lpProps[0]), PR_SEND_INTERNET_ENCODING, (const void *)&val);
@@ -400,8 +394,8 @@ exchange_mapi_cal_util_fetch_recipients (ECalComponent *comp, GSList **recip_lis
 		set_SPropValue_proptag (&(recipient->in.req_lpProps[4]), PR_RECIPIENT_DISPLAY_NAME, (const void *)(str));
 
 		/* External recipient properties - set them only when the recipient is unresolved */
+		recipient->in.ext_lpProps = g_new0 (struct SPropValue, 7);
 		recipient->in.ext_cValues = 7;
-		recipient->in.ext_lpProps = g_new0 (struct SPropValue, recipient->in.ext_cValues + 1);
 
 		val = DT_MAILUSER;
 		set_SPropValue_proptag (&(recipient->in.ext_lpProps[0]), PR_DISPLAY_TYPE, (const void *)&val);
@@ -493,15 +487,15 @@ ical_attendees_from_props (icalcomponent *ical_comp, GSList *recipients, gboolea
 		else 
 			continue;
 
-		flags = (const uint32_t *) get_SPropValue_SRow_data (&recip->out_SRow, PR_RECIPIENTS_FLAGS);
+		flags = (const uint32_t *) get_SPropValue(recip->out.all_lpProps, PR_RECIPIENTS_FLAGS);
 
 		if (flags && (*flags & RECIP_ORGANIZER)) {
 			prop = icalproperty_new_organizer (val);
 
 			/* CN */
-			str = (const char *) exchange_mapi_util_find_row_propval (&recip->out_SRow, PR_RECIPIENT_DISPLAY_NAME);
+			str = (const char *) exchange_mapi_util_find_SPropVal_array_propval(recip->out.all_lpProps, PR_RECIPIENT_DISPLAY_NAME);
 			if (!str)
-				str = (const char *) exchange_mapi_util_find_row_propval (&recip->out_SRow, PR_DISPLAY_NAME);
+				str = (const char *) exchange_mapi_util_find_SPropVal_array_propval(recip->out.all_lpProps, PR_DISPLAY_NAME);
 			if (str) {
 				param = icalparameter_new_cn (str);
 				icalproperty_add_parameter (prop, param);
@@ -510,9 +504,9 @@ ical_attendees_from_props (icalcomponent *ical_comp, GSList *recipients, gboolea
 			prop = icalproperty_new_attendee (val);
 
 			/* CN */
-			str = (const char *) exchange_mapi_util_find_row_propval (&recip->out_SRow, PR_RECIPIENT_DISPLAY_NAME);
+			str = (const char *) exchange_mapi_util_find_SPropVal_array_propval(recip->out.all_lpProps, PR_RECIPIENT_DISPLAY_NAME);
 			if (!str)
-				str = (const char *) exchange_mapi_util_find_row_propval (&recip->out_SRow, PR_DISPLAY_NAME);
+				str = (const char *) exchange_mapi_util_find_SPropVal_array_propval(recip->out.all_lpProps, PR_DISPLAY_NAME);
 			if (str) {
 				param = icalparameter_new_cn (str);
 				icalproperty_add_parameter (prop, param);
@@ -521,11 +515,11 @@ ical_attendees_from_props (icalcomponent *ical_comp, GSList *recipients, gboolea
 			param = icalparameter_new_rsvp (rsvp ? ICAL_RSVP_TRUE : ICAL_RSVP_FALSE);
 			icalproperty_add_parameter (prop, param);
 			/* PARTSTAT */
-			ui32 = (const uint32_t *) get_SPropValue_SRow_data (&recip->out_SRow, PR_RECIPIENT_TRACKSTATUS);
+			ui32 = (const uint32_t *) get_SPropValue(recip->out.all_lpProps, PR_RECIPIENT_TRACKSTATUS);
 			param = icalparameter_new_partstat (get_partstat_from_trackstatus (ui32 ? *ui32 : olResponseNone));
 			icalproperty_add_parameter (prop, param);
 			/* ROLE */
-			ui32 = (const uint32_t *) get_SPropValue_SRow_data (&recip->out_SRow, PR_RECIPIENT_TYPE);
+			ui32 = (const uint32_t *) get_SPropValue(recip->out.all_lpProps, PR_RECIPIENT_TYPE);
 			param = icalparameter_new_role (get_role_from_type (ui32 ? *ui32 : olTo));
 			icalproperty_add_parameter (prop, param);
 #if 0
@@ -733,7 +727,7 @@ exchange_mapi_cal_util_mapi_props_to_comp (icalcomponent_kind kind, const gchar
 
 	if (icalcomponent_isa (ical_comp) == ICAL_VEVENT_COMPONENT) {
 		const char *location = NULL;
-		const gchar *dtstart_tz_location = NULL, *dtend_tz_location = NULL;
+		const gchar *dtstart_tz = NULL, *dtend_tz = NULL;
 		ExchangeMAPIStream *stream;
 
 		/* CleanGlobalObjectId */
@@ -775,33 +769,29 @@ exchange_mapi_cal_util_mapi_props_to_comp (icalcomponent_kind kind, const gchar
 		stream = exchange_mapi_util_find_stream (streams, PROP_TAG(PT_BINARY, 0x825E));
 		if (stream) {
 			gchar *buf = exchange_mapi_cal_util_bin_to_mapi_tz (stream->value);
-			dtstart_tz_location = exchange_mapi_cal_tz_util_get_ical_equivalent (buf);
+			dtstart_tz = exchange_mapi_cal_tz_util_get_ical_equivalent (buf);
 			g_free (buf);
 		}
 
 		if (get_mapi_SPropValue_array_date_timeval (&t, properties, PROP_TAG(PT_SYSTIME, 0x820D)) == MAPI_E_SUCCESS) {
-			icaltimezone *zone = dtstart_tz_location ? icaltimezone_get_builtin_timezone (dtstart_tz_location) : (icaltimezone *)default_zone;
+			icaltimezone *zone = dtstart_tz ? icaltimezone_get_builtin_timezone_from_tzid (dtstart_tz) : (icaltimezone *)default_zone;
 			prop = icalproperty_new_dtstart (icaltime_from_timet_with_zone (t.tv_sec, (b && *b), zone));
-			if (zone && icaltimezone_get_tzid (zone)) {
-				icalproperty_add_parameter (prop, icalparameter_new_tzid (icaltimezone_get_tzid (zone)));
-				icalcomponent_add_property (ical_comp, prop);
-			}
+			icalproperty_add_parameter (prop, icalparameter_new_tzid(dtstart_tz));
+			icalcomponent_add_property (ical_comp, prop);
 		}
 
 		stream = exchange_mapi_util_find_stream (streams, PROP_TAG(PT_BINARY, 0x825F));
 		if (stream) {
 			gchar *buf = exchange_mapi_cal_util_bin_to_mapi_tz (stream->value);
-			dtend_tz_location = exchange_mapi_cal_tz_util_get_ical_equivalent (buf);
+			dtend_tz = exchange_mapi_cal_tz_util_get_ical_equivalent (buf);
 			g_free (buf);
 		}
 
 		if (get_mapi_SPropValue_array_date_timeval (&t, properties, PROP_TAG(PT_SYSTIME, 0x820E)) == MAPI_E_SUCCESS) {
-			icaltimezone *zone = dtend_tz_location ? icaltimezone_get_builtin_timezone (dtend_tz_location) : (icaltimezone *)default_zone;
+			icaltimezone *zone = dtend_tz ? icaltimezone_get_builtin_timezone_from_tzid (dtend_tz) : (icaltimezone *)default_zone;
 			prop = icalproperty_new_dtend (icaltime_from_timet_with_zone (t.tv_sec, (b && *b), zone));
-			if (zone && icaltimezone_get_tzid (zone)) {
-				icalproperty_add_parameter (prop, icalparameter_new_tzid (icaltimezone_get_tzid (zone)));
-				icalcomponent_add_property (ical_comp, prop);
-			}
+			icalproperty_add_parameter (prop, icalparameter_new_tzid(dtend_tz));
+			icalcomponent_add_property (ical_comp, prop);
 		}
 
 		ui32 = (const uint32_t *)find_mapi_SPropValue_data(properties, PROP_TAG(PT_LONG, 0x8205));
@@ -1067,7 +1057,7 @@ update_attendee_status (struct mapi_SPropValue_array *properties, mapi_id_t mid)
 	const gchar *att, *att_sentby, *addrtype;
 	icalparameter_partstat partstat = ICAL_PARTSTAT_NONE;
 	const gchar *state = (const gchar *) exchange_mapi_util_find_array_propval (properties, PR_MESSAGE_CLASS);
-	struct cbdata cbdata; 
+	struct cbdata cbdata = { 0 };
 	gchar *matt, *matt_sentby;
 	uint32_t cur_seq;
 	const uint32_t *ui32;
@@ -1127,8 +1117,6 @@ update_attendee_status (struct mapi_SPropValue_array *properties, mapi_id_t mid)
 		cbdata.is_modify = TRUE;
 		cbdata.cleanglobalid = (const struct SBinary *)find_mapi_SPropValue_data(properties, PROP_TAG(PT_BINARY, 0x0023));
 		cbdata.globalid = (const struct SBinary *)find_mapi_SPropValue_data(properties, PROP_TAG(PT_BINARY, 0x0003));
-		cbdata.get_timezone = NULL;
-		cbdata.get_tz_data = NULL;
 
 		status = exchange_mapi_modify_item (olFolderCalendar, fid, mid, 
 				exchange_mapi_cal_util_build_name_id, GINT_TO_POINTER (kind), 
@@ -1145,6 +1133,7 @@ update_attendee_status (struct mapi_SPropValue_array *properties, mapi_id_t mid)
 		/* remove the other attendees so not to confuse itip-formatter */
 		remove_other_attendees (cbdata.comp, matt);
 	} else { 
+		g_free (cbdata.props);
 		g_object_unref (cbdata.comp);
 		cbdata.comp = NULL;
 	}
@@ -1169,7 +1158,7 @@ update_server_object (struct mapi_SPropValue_array *properties, GSList *attachme
 	cur_seq = ui32 ? *ui32 : 0;
 
 	if (*mid) {
-		struct cbdata server_cbd;
+		struct cbdata server_cbd = {0};
 		fetch_server_data (*mid, &server_cbd);
 
 		if (cur_seq > server_cbd.appt_seq) {
@@ -1183,10 +1172,14 @@ update_server_object (struct mapi_SPropValue_array *properties, GSList *attachme
 			g_slist_free (ids);
 		} else 
 			create_new = FALSE;
+
+		if (server_cbd.comp)
+			g_object_unref (server_cbd.comp);
+		g_free (server_cbd.props);
 	}
 
 	if (create_new) {
-		struct cbdata cbdata;
+		struct cbdata cbdata = { 0 };
 		GSList *myrecipients = NULL;
 		GSList *myattachments = NULL;
 		icalcomponent_kind kind = icalcomponent_isa (e_cal_component_get_icalcomponent(comp));
@@ -1206,8 +1199,6 @@ update_server_object (struct mapi_SPropValue_array *properties, GSList *attachme
 		cbdata.appt_id = (*(const uint32_t *)find_mapi_SPropValue_data(properties, PR_OWNER_APPT_ID));
 		cbdata.globalid = (const struct Binary_r *)find_mapi_SPropValue_data(properties, PROP_TAG(PT_BINARY, 0x0003));
 		cbdata.cleanglobalid = (const struct Binary_r *)find_mapi_SPropValue_data(properties, PROP_TAG(PT_BINARY, 0x0023));
-		cbdata.get_timezone = NULL;
-		cbdata.get_tz_data = NULL;
 
 		exchange_mapi_cal_util_fetch_recipients (comp, &myrecipients);
 		myattachments = attachments;
@@ -1253,7 +1244,7 @@ check_server_for_object (struct mapi_SPropValue_array *properties, mapi_id_t *mi
 		struct id_list *idlist = (struct id_list *)(ids->data);
 		*mid = idlist->id;
 	} else  {
-	/* FIXME: what to do here? */
+		/* FIXME: what to do here? */
 	}
 
 	for (l = ids; l; l = l->next)
@@ -1299,10 +1290,12 @@ exchange_mapi_cal_util_camel_helper (struct mapi_SPropValue_array *properties,
 		} 
 	} else if (method == ICAL_METHOD_CANCEL) {
 		if (mid) {
-			struct cbdata server_cbd; 
+			struct cbdata server_cbd = { 0 };
 			fetch_server_data (mid, &server_cbd);
 			comp = server_cbd.comp;
 			set_attachments_to_cal_component (comp, attachments, fileuri);
+
+			g_free (server_cbd.props);
 		}
 	} else if (method == ICAL_METHOD_REQUEST) { 
 		if (mid)
@@ -1561,32 +1554,6 @@ note_build_name_id (struct mapi_nameid *nameid)
 	mapi_nameid_lid_add(nameid, 0x8B03, PSETID_Note); 	// PT_LONG - Height
 }
 
-/* retrieves timezone location from a timezone ID */
-static const gchar *
-get_tzid_location (const gchar *tzid, struct cbdata *cbdata)
-{
-	icaltimezone *zone;
-
-	if (!tzid || !*tzid || g_str_equal (tzid, "UTC"))
-		return NULL;
-
-	zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
-
-	if (!zone && g_str_has_prefix (tzid, OLD_TZID_PREFIX))
-		zone = icaltimezone_get_builtin_timezone (tzid + strlen (OLD_TZID_PREFIX));
-
-	if (!zone) {
-		/* it is not a buildin time zone, try ask backend for it */
-		if (cbdata && cbdata->get_timezone)
-			zone = cbdata->get_timezone (cbdata->get_tz_data, tzid);
-	}
-
-	if (!zone)
-		return NULL;
-
-	return icaltimezone_get_location (zone);
-}
-
 #define MINUTES_IN_HOUR 60
 #define SECS_IN_MINUTE 60
 
@@ -1610,7 +1577,7 @@ exchange_mapi_cal_util_build_props (struct SPropValue **value, struct SPropTagAr
 	icalproperty *prop;
 	struct icaltimetype dtstart, dtend, utc_dtstart, utc_dtend;
 	const icaltimezone *utc_zone;
-	const char *dtstart_tz_location, *dtend_tz_location, *text = NULL;
+	const char *dtstart_tzid, *dtend_tzid, *text = NULL;
 	struct timeval t;
 
 	flag32 = REGULAR_PROPS_N + COMMON_NAMED_PROPS_N;
@@ -1629,7 +1596,7 @@ exchange_mapi_cal_util_build_props (struct SPropValue **value, struct SPropTagAr
 	} 
 
 	d(g_debug ("Allocating space for %d props ", flag32));
-	props = g_new0 (struct SPropValue, flag32 + 1);
+	props = g_new0 (struct SPropValue, flag32);
 
 	/* PR_MESSAGE_CLASS needs to be set appropriately */					/* propcount++ */
 
@@ -1646,8 +1613,8 @@ exchange_mapi_cal_util_build_props (struct SPropValue **value, struct SPropTagAr
 	else 
 		dtend = icalcomponent_get_dtstart (ical_comp);
 
-	dtstart_tz_location = get_tzid_location (icaltime_get_tzid (dtstart), cbdata);
-	dtend_tz_location = get_tzid_location (icaltime_get_tzid (dtend), cbdata);
+	dtstart_tzid = icaltime_get_tzid (dtstart);
+	dtend_tzid = icaltime_get_tzid (dtend);
 
 	utc_dtstart = icaltime_convert_to_zone (dtstart, (icaltimezone *)utc_zone);
 	utc_dtend = icaltime_convert_to_zone (dtend, (icaltimezone *)utc_zone);
@@ -1818,7 +1785,7 @@ exchange_mapi_cal_util_build_props (struct SPropValue **value, struct SPropTagAr
 		set_SPropValue_proptag_date_timeval(&props[i++], proptag_array->aulPropTag[I_APPT_CLIPSTART], &t);
 
 		/* Start TZ */
-		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtstart_tz_location && *dtstart_tz_location) ? dtstart_tz_location : "UTC");
+		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtstart_tzid && *dtstart_tzid) ? dtstart_tzid : "UTC");
 		if (mapi_tzid && *mapi_tzid) {
 			exchange_mapi_cal_util_mapi_tz_to_bin (mapi_tzid, &start_tz);
 			set_SPropValue_proptag(&props[i++], proptag_array->aulPropTag[I_APPT_STARTTZBLOB], (const void *) &start_tz);
@@ -1832,7 +1799,7 @@ exchange_mapi_cal_util_build_props (struct SPropValue **value, struct SPropTagAr
 		set_SPropValue_proptag_date_timeval(&props[i++], proptag_array->aulPropTag[I_APPT_CLIPEND], &t);
 
 		/* End TZ */
-		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtend_tz_location && *dtend_tz_location) ? dtend_tz_location : "UTC");
+		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtend_tzid && *dtend_tzid) ? dtend_tzid : "UTC");
 		if (mapi_tzid && *mapi_tzid) {
 			exchange_mapi_cal_util_mapi_tz_to_bin (mapi_tzid, &end_tz);
 			set_SPropValue_proptag(&props[i++], proptag_array->aulPropTag[I_APPT_ENDTZBLOB], (const void *) &end_tz);
